@@ -8,9 +8,11 @@ test_that("weather_raw() hour column names as expected", {
   wd <- weather_html(station_id = 51423,
                      date = as.Date("2014-01-01"),
                      interval = "hour") %>%
-    weather_raw(skip = 15)
+    weather_raw()
 
-  expect_true(all(names(wd) %in% w_names$hour))
+  expect_true(all(names(wd) %in% c(w_names$hour,
+                                   "Latitude (y)", "Longitude (x)",
+                                   "Station Name", "Climate ID")))
 
   # Data quality no longer present
   temp <- w_names$hour[w_names$hour != "Data Quality"]
@@ -24,9 +26,11 @@ test_that("weather_raw() day column names as expected", {
   wd <- weather_html(station_id = 51423,
                      date = as.Date("2014-01-01"),
                      interval = "day") %>%
-    weather_raw(skip = 24)
+    weather_raw()
 
-  expect_true(all(names(wd) %in% w_names$day))
+  expect_true(all(names(wd) %in% c(w_names$day,
+                                   "Latitude (y)", "Longitude (x)",
+                                   "Station Name", "Climate ID")))
   expect_true(all(w_names$day %in% names(wd)))
 })
 
@@ -37,9 +41,11 @@ test_that("weather_raw() month column names as expected", {
   wd <- weather_html(station_id = 43823,
                      date = as.Date("2005-01-01"),
                      interval = "month") %>%
-    weather_raw(skip = 17)
+    weather_raw()
 
-  expect_true(all(names(wd) %in% w_names$month))
+  expect_true(all(names(wd) %in% c(w_names$month,
+                                   "Latitude (y)", "Longitude (x)",
+                                   "Station Name", "Climate ID")))
   expect_true(all(w_names$month %in% names(wd)))
 })
 
